<?php

namespace Drupal\commerce_user_points\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Url;

/**
 * Provides a 'Referral Link' block.
 *
 * @Block(
 *   id = "user_referral_link",
 *   admin_label = @Translation("Referral Link")
 * )
 */
class ReferralLinkBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return ['label_display' => FALSE];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $referralLink = "";
    $uid = \Drupal::currentUser()->id();
    if ($uid != NULL) {
      $referralService = \Drupal::service('commerce_user_points.referral_link');
      $referralLinkCode = $referralService->getLink('uid', $uid);

      if (isset($referralLinkCode) && !empty($referralLinkCode)) {
        $linkCode = $referralLinkCode['referral_link_code'];
        $frontPage = Url::fromRoute('<front>')->setAbsolute()->toString();
        $referralLink = $frontPage . '/user/register/referral/' . $linkCode;
      }
    }

    $renderable = [
      '#theme' => 'user_referral_link',
      '#referral_link' => $referralLink,
      '#attached' => [
        'library' => [
          'commerce_user_points/referral_link_library',
        ],
      ],
    ];
    return $renderable;
  }

}
